@@ -19,16 +19,15 @@
 #include "session.h"
 
 #include <QUrl>
-#include <QtCore/QPointer>
-
-namespace KManageSieve
-{
+#include <QPointer>
 
+namespace KManageSieve {
 class SieveJob::Private
 {
 public:
     Private(SieveJob *qq)
-        : q(qq), mFileExists(DontKnow)
+        : q(qq)
+        , mFileExists(DontKnow)
     {
     }
 
@@ -71,7 +70,6 @@ public:
 
     static QHash<QUrl, QPointer<Session> > m_sessionPool;
 };
-
 }
 
 #endif
