@@ -21,9 +21,8 @@
 
 #include <QObject>
 #include <QUrl>
-class QDomElement;
-namespace KSieveUi
-{
+class QXmlStreamReader;
+namespace KSieveUi {
 class SieveImapAccountSettings;
 class SieveEditorGraphicalModeWidget;
 class SieveAction : public QObject
@@ -38,7 +37,7 @@ public:
 
     virtual QWidget *createParamWidget(QWidget *parent) const;
 
-    virtual bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error);
+    virtual bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error);
 
     virtual QString code(QWidget *) const;
 
@@ -55,9 +54,9 @@ public:
 
     void setComment(const QString &comment);
 
-    void unknownTag(const QString &tag, QString &error);
+    void unknownTag(const QStringRef &tag, QString &error);
     void unknowTagValue(const QString &tagValue, QString &error);
-    void tooManyArgument(const QString &tagName, int index, int maxValue, QString &error);
+    void tooManyArgument(const QStringRef &tagName, int index, int maxValue, QString &error);
     void serverDoesNotSupportFeatures(const QString &feature, QString &error);
 
 protected:
