@@ -25,7 +25,7 @@
 
 #include <QLabel>
 #include <QHBoxLayout>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
@@ -50,28 +50,26 @@ QWidget *SieveActionEReject::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionEReject::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
+bool SieveActionEReject::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("str")) {
-                const QString tagValue = e.text();
-                MultiLineEdit *edit = w->findChild<MultiLineEdit *>(QStringLiteral("rejectmessage"));
-                edit->setPlainText(AutoCreateScriptUtil::quoteStr(tagValue));
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
-            } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveActionEReject::setParamWidgetValue unknown tagName " << tagName;
-            }
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("str")) {
+            const QString tagValue = element.readElementText();
+            MultiLineEdit *edit = w->findChild<MultiLineEdit *>(QStringLiteral("rejectmessage"));
+            edit->setPlainText(tagValue);
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            element.skipCurrentElement();
+            //implement in the future ?
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveActionEReject::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+
     return true;
 }
 
