@@ -23,8 +23,7 @@
 #include <QWidget>
 #include <KSieveUi/AbstractMoveImapFolderWidget>
 class QLineEdit;
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveImapAccountSettings;
 class MoveImapFolderWidget : public KSieveUi::AbstractMoveImapFolderWidget
 {
@@ -33,10 +32,10 @@ public:
     explicit MoveImapFolderWidget(QWidget *parent = nullptr);
     ~MoveImapFolderWidget();
 
-    void setText(const QString &str) Q_DECL_OVERRIDE;
-    QString text() const Q_DECL_OVERRIDE;
+    void setText(const QString &str) override;
+    QString text() const override;
 
-    void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account) Q_DECL_OVERRIDE;
+    void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account) override;
 private:
     QLineEdit *mLineEdit;
 };
