@@ -21,22 +21,21 @@
 
 #include "sievecondition.h"
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveConditionSize : public SieveCondition
 {
     Q_OBJECT
 public:
     explicit SieveConditionSize(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
 
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const override;
 
-    QString code(QWidget *parent) const Q_DECL_OVERRIDE;
+    QString code(QWidget *parent) const override;
 
-    QString help() const Q_DECL_OVERRIDE;
+    QString help() const override;
 
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error) Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, bool notCondition, QString &error) override;
+    QUrl href() const override;
 };
 }
 
