@@ -56,7 +56,7 @@ QStringList SelectAddressPartComboBox::extraRequire() const
 {
     QStringList lst;
     if (mHasSubaddressCapability) {
-        lst = QStringList() << QStringLiteral("subaddress");
+        lst << QStringLiteral("subaddress");
     }
     return lst;
 }
@@ -71,4 +71,3 @@ void SelectAddressPartComboBox::setCode(const QString &code, const QString &name
         setCurrentIndex(0);
     }
 }
-
