@@ -20,6 +20,7 @@
 #include "sieveconditionwidgetlister.h"
 #include "autocreatescriptdialog.h"
 #include "autocreatescriptutil_p.h"
+#include "libksieve_debug.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "sieveeditorgraphicalmodewidget.h"
 #include "sieveconditions/sieveconditionlist.h"
@@ -34,6 +35,7 @@
 #include <QLabel>
 #include <QWhatsThis>
 #include "libksieve_debug.h"
+#include "sievescriptdescriptiondialog.h"
 #include <QDomElement>
 
 using namespace KSieveUi;
@@ -42,8 +44,8 @@ static const int MINIMUMCONDITION = 1;
 static const int MAXIMUMCONDITION = 8;
 
 SieveConditionWidget::SieveConditionWidget(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent)
-    : QWidget(parent),
-      mSieveGraphicalModeWidget(sieveGraphicalModeWidget)
+    : QWidget(parent)
+    , mSieveGraphicalModeWidget(sieveGraphicalModeWidget)
 {
     initWidget();
 }
@@ -56,23 +58,24 @@ SieveConditionWidget::~SieveConditionWidget()
 
 void SieveConditionWidget::setFilterCondition(QWidget *widget)
 {
-    if (mLayout->itemAtPosition(1, 2)) {
-        delete mLayout->itemAtPosition(1, 2)->widget();
+    if (mLayout->itemAtPosition(1, 3)) {
+        delete mLayout->itemAtPosition(1, 3)->widget();
     }
 
     if (widget) {
-        mLayout->addWidget(widget, 1, 2);
+        mLayout->addWidget(widget, 1, 3);
     } else {
-        mLayout->addWidget(new QLabel(i18n("Please select an condition."), this), 1, 2);
+        mLayout->addWidget(new QLabel(i18n("Please select an condition."), this), 1, 3);
     }
 }
 
-void SieveConditionWidget::generatedScript(QString &script, QStringList &requires)
+void SieveConditionWidget::generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop)
 {
+    Q_UNUSED(inForEveryPartLoop);
     const int index = mComboBox->currentIndex();
     if (index != mComboBox->count() - 1) {
         KSieveUi::SieveCondition *widgetCondition = mConditionList.at(mComboBox->currentIndex());
-        QWidget *currentWidget = mLayout->itemAtPosition(1, 2)->widget();
+        QWidget *currentWidget = mLayout->itemAtPosition(1, 3)->widget();
         const QStringList lstRequires = widgetCondition->needRequires(currentWidget);
         for (const QString &r : lstRequires) {
             if (!requires.contains(r)) {
@@ -116,13 +119,17 @@ void SieveConditionWidget::initWidget()
     }
 
     mHelpButton = new SieveHelpButton(this);
-    mHelpButton->setEnabled(false);
     mLayout->addWidget(mHelpButton, 1, 0);
     connect(mHelpButton, &SieveHelpButton::clicked, this, &SieveConditionWidget::slotHelp);
 
+    mCommentButton = new QToolButton(this);
+    mCommentButton->setToolTip(i18n("Add comment"));
+    mLayout->addWidget(mCommentButton, 1, 1);
+    mCommentButton->setIcon(QIcon::fromTheme(QStringLiteral("view-pim-notes")));
+    connect(mCommentButton, &QToolButton::clicked, this, &SieveConditionWidget::slotAddComment);
+
     mComboBox->addItem(QLatin1String(""));
-    mComboBox->setCurrentIndex(mComboBox->count() - 1);
-    mLayout->addWidget(mComboBox, 1, 1);
+    mLayout->addWidget(mComboBox, 1, 2);
     connect(mComboBox, static_cast<void (PimCommon::MinimumComboBox::*)(int)>(&PimCommon::MinimumComboBox::activated), this, &SieveConditionWidget::slotConditionChanged);
 
     mComboBox->setMaxCount(mComboBox->count());
@@ -138,15 +145,32 @@ void SieveConditionWidget::initWidget()
     mRemove->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
     mRemove->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
 
-    mLayout->addWidget(mAdd, 1, 3);
-    mLayout->addWidget(mRemove, 1, 4);
+    mLayout->addWidget(mAdd, 1, 4);
+    mLayout->addWidget(mRemove, 1, 5);
 
     // redirect focus to the filter action combo box
     setFocusProxy(mComboBox);
 
     connect(mAdd, &QPushButton::clicked, this, &SieveConditionWidget::slotAddWidget);
     connect(mRemove, &QPushButton::clicked, this, &SieveConditionWidget::slotRemoveWidget);
-    setFilterCondition(nullptr);
+
+    clear();
+}
+
+void SieveConditionWidget::slotAddComment()
+{
+    const int index = mComboBox->currentIndex();
+    if (index < mConditionList.count()) {
+        KSieveUi::SieveCondition *condition = mConditionList.at(index);
+        const QString comment = condition->comment();
+        QPointer<SieveScriptDescriptionDialog> dlg = new SieveScriptDescriptionDialog;
+        dlg->setDescription(comment);
+        if (dlg->exec()) {
+            condition->setComment(dlg->description());
+            Q_EMIT valueChanged();
+        }
+        delete dlg;
+    }
 }
 
 void SieveConditionWidget::slotHelp()
@@ -167,9 +191,11 @@ void SieveConditionWidget::slotConditionChanged(int index)
         KSieveUi::SieveCondition *condition = mConditionList.at(index);
         mHelpButton->setEnabled(!condition->help().isEmpty());
         setFilterCondition(condition->createParamWidget(this));
+        mCommentButton->setEnabled(true);
     } else {
         setFilterCondition(nullptr);
         mHelpButton->setEnabled(false);
+        mCommentButton->setEnabled(false);
     }
     Q_EMIT valueChanged();
 }
@@ -186,9 +212,12 @@ void SieveConditionWidget::slotRemoveWidget()
     Q_EMIT valueChanged();
 }
 
-void SieveConditionWidget::reset()
+void SieveConditionWidget::clear()
 {
-    //TODO
+    mComboBox->setCurrentIndex(mComboBox->count() - 1);
+    setFilterCondition(nullptr);
+    mHelpButton->setEnabled(false);
+    mCommentButton->setEnabled(false);
 }
 
 void SieveConditionWidget::updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled)
@@ -197,7 +226,7 @@ void SieveConditionWidget::updateAddRemoveButton(bool addButtonEnabled, bool rem
     mRemove->setEnabled(removeButtonEnabled);
 }
 
-void SieveConditionWidget::setCondition(const QString &conditionName, const QDomElement &element, bool notCondition, QString &error)
+void SieveConditionWidget::setCondition(const QString &conditionName, QXmlStreamReader &element, bool notCondition, QString &error)
 {
     const int index = mComboBox->findData(conditionName);
     if (index != -1) {
@@ -205,12 +234,16 @@ void SieveConditionWidget::setCondition(const QString &conditionName, const QDom
         slotConditionChanged(index);
         KSieveUi::SieveCondition *condition = mConditionList.at(index);
         condition->setParamWidgetValue(element, this, notCondition, error);
+    } else {
+        error += i18n("Script contains unsupported feature \"%1\"", conditionName) + QLatin1Char('\n');
+        qCDebug(LIBKSIEVE_LOG) << "Condition " << conditionName << " not supported";
+        element.skipCurrentElement();
     }
 }
 
 SieveConditionWidgetLister::SieveConditionWidgetLister(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent)
-    : KPIM::KWidgetLister(false, MINIMUMCONDITION, MAXIMUMCONDITION, parent),
-      mSieveGraphicalModeWidget(sieveGraphicalModeWidget)
+    : KPIM::KWidgetLister(false, MINIMUMCONDITION, MAXIMUMCONDITION, parent)
+    , mSieveGraphicalModeWidget(sieveGraphicalModeWidget)
 {
     slotClear();
     updateAddRemoveButton();
@@ -218,7 +251,6 @@ SieveConditionWidgetLister::SieveConditionWidgetLister(SieveEditorGraphicalModeW
 
 SieveConditionWidgetLister::~SieveConditionWidgetLister()
 {
-
 }
 
 void SieveConditionWidgetLister::slotAddWidget(QWidget *w)
@@ -266,8 +298,10 @@ void SieveConditionWidgetLister::reconnectWidget(SieveConditionWidget *w)
 
 void SieveConditionWidgetLister::clearWidget(QWidget *aWidget)
 {
-    //TODO
-    Q_UNUSED(aWidget);
+    if (aWidget) {
+        SieveConditionWidget *widget = static_cast<SieveConditionWidget *>(aWidget);
+        widget->clear();
+    }
     Q_EMIT valueChanged();
 }
 
@@ -278,7 +312,7 @@ QWidget *SieveConditionWidgetLister::createWidget(QWidget *parent)
     return w;
 }
 
-void SieveConditionWidgetLister::generatedScript(QString &script, int &numberOfCondition, QStringList &requires)
+void SieveConditionWidgetLister::generatedScript(QString &script, int &numberOfCondition, QStringList &requires, bool inForEveryPartLoop)
 {
     const QList<QWidget *> widgetList = widgets();
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
@@ -287,9 +321,12 @@ void SieveConditionWidgetLister::generatedScript(QString &script, int &numberOfC
     for (; wIt != wEnd; ++wIt) {
         QString condition;
         SieveConditionWidget *w = qobject_cast<SieveConditionWidget *>(*wIt);
-        w->generatedScript(condition, requires);
+        w->generatedScript(condition, requires, inForEveryPartLoop);
         if (!condition.isEmpty()) {
             if (!wasFirst) {
+                if (inForEveryPartLoop) {
+                    script += AutoCreateScriptUtil::indentation();
+                }
                 script += QLatin1String(", ");
             }
             script += condition;
@@ -304,80 +341,70 @@ int SieveConditionWidgetLister::conditionNumber() const
     return widgets().count();
 }
 
-void SieveConditionWidgetLister::loadTest(const QDomElement &element, bool notCondition, QString &error)
+void SieveConditionWidgetLister::loadTest(QXmlStreamReader &element, bool notCondition, QString &error)
 {
-    QDomElement testElement = element;
     if (notCondition) {
-        QDomNode node = element.firstChild();
-        if (!node.isNull()) {
-            testElement = node.toElement();
-        }
+        element.readNextStartElement();
     }
-    if (testElement.hasAttribute(QStringLiteral("name"))) {
-        const QString conditionName = testElement.attribute(QStringLiteral("name"));
+    if (element.attributes().hasAttribute(QStringLiteral("name"))) {
+        const QString conditionName = element.attributes().value(QStringLiteral("name")).toString();
         SieveConditionWidget *w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
-        w->setCondition(conditionName, testElement, notCondition, error);
+        w->setCondition(conditionName, element, notCondition, error);
+    }
+    if (notCondition) {
+        element.skipCurrentElement();
     }
 }
 
-void SieveConditionWidgetLister::loadScript(const QDomElement &e, bool uniqTest, bool notCondition, QString &error)
+void SieveConditionWidgetLister::loadScript(QXmlStreamReader &element, bool uniqTest, bool notCondition, QString &error)
 {
     if (uniqTest) {
-        loadTest(e, notCondition, error);
+        loadTest(element, notCondition, error);
     } else {
         bool firstCondition = true;
-        QDomElement element = e;
         if (notCondition) {
-            QDomNode node = e.firstChild();
-            if (!node.isNull()) {
-                element = node.toElement();
-            }
+            element.readNextStartElement();
         }
-        QDomNode node = element.firstChild();
-        while (!node.isNull()) {
-            QDomElement e = node.toElement();
-            if (!e.isNull()) {
-                const QString tagName = e.tagName();
-                if (tagName == QLatin1String("testlist")) {
-                    QDomNode testNode = e.firstChild();
-                    while (!testNode.isNull()) {
-                        QDomElement testElement = testNode.toElement();
-                        if (!testElement.isNull()) {
-                            const QString testTagName = testElement.tagName();
-                            if (testTagName == QLatin1String("test")) {
-                                if (testElement.hasAttribute(QStringLiteral("name"))) {
-                                    QString conditionName = testElement.attribute(QStringLiteral("name"));
-                                    if (firstCondition) {
-                                        firstCondition = false;
-                                    } else {
-                                        addWidgetAfterThisWidget(widgets().constLast());
-                                    }
-                                    SieveConditionWidget *w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
-                                    if (conditionName == QLatin1String("not")) {
-                                        notCondition = true;
-                                        QDomNode notNode = testElement.firstChild();
-                                        QDomElement notElement = notNode.toElement();
-                                        if (notElement.hasAttribute(QStringLiteral("name"))) {
-                                            conditionName = notElement.attribute(QStringLiteral("name"));
-                                        }
-                                        w->setCondition(conditionName, notElement, notCondition, error);
-                                    } else {
-                                        notCondition = false;
-                                        w->setCondition(conditionName, testElement, notCondition, error);
-                                    }
-                                }
-                            } else if (testTagName == QLatin1String("crlf")) {
-                                //nothing
+        while (element.readNextStartElement()) {
+            const QStringRef tagName = element.name();
+            if (tagName == QLatin1String("testlist")) {
+                while (element.readNextStartElement()) {
+                    const QStringRef testTagName = element.name();
+                    if (testTagName == QLatin1String("test")) {
+                        if (element.attributes().hasAttribute(QStringLiteral("name"))) {
+                            QString conditionName = element.attributes().value(QStringLiteral("name")).toString();
+                            if (firstCondition) {
+                                firstCondition = false;
                             } else {
-                                qCDebug(LIBKSIEVE_LOG) << " SieveConditionWidgetLister::loadScript unknown condition tag: " << testTagName;
+                                addWidgetAfterThisWidget(widgets().constLast());
+                            }
+                            SieveConditionWidget *w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
+                            if (conditionName == QLatin1String("not")) {
+                                notCondition = true;
+                                element.readNextStartElement();
+                                if (element.attributes().hasAttribute(QStringLiteral("name"))) {
+                                    conditionName = element.attributes().value(QStringLiteral("name")).toString();
+                                }
+                                w->setCondition(conditionName, element, notCondition, error);
+                                element.skipCurrentElement();
+                            } else {
+                                notCondition = false;
+                                w->setCondition(conditionName, element, notCondition, error);
                             }
                         }
-                        testNode = testNode.nextSibling();
+                    } else if (testTagName == QLatin1String("crlf")) {
+                        element.skipCurrentElement();
+                        //nothing
+                    } else if (testTagName == QLatin1String("comment")) {
+                        qDebug() << "Need to implement comment here ";
+                        element.skipCurrentElement();
+                        //nothing
+                        //implement in the future ?
+                    } else {
+                        qCDebug(LIBKSIEVE_LOG) << " SieveConditionWidgetLister::loadScript unknown condition tag: " << testTagName;
                     }
                 }
             }
-            node = node.nextSibling();
         }
     }
 }
-
