@@ -22,6 +22,7 @@
 #include "autocreatescriptutil_p.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "editor/sieveeditorutil.h"
+#include "widgets/lineeditvalidator.h"
 
 #include <QPushButton>
 #include <KLocalizedString>
@@ -33,7 +34,7 @@
 #include <QLabel>
 #include <QWhatsThis>
 #include "libksieve_debug.h"
-#include <QDomNode>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 static const int MINIMUMGLOBALVARIABLEACTION = 1;
@@ -47,13 +48,12 @@ SieveGlobalVariableActionWidget::SieveGlobalVariableActionWidget(QWidget *parent
 
 SieveGlobalVariableActionWidget::~SieveGlobalVariableActionWidget()
 {
-
 }
 
 void SieveGlobalVariableActionWidget::generatedScript(QString &script)
 {
     const QString variableName = mVariableName->text();
-    if (variableName.isEmpty()) {
+    if (variableName.trimmed().isEmpty()) {
         return;
     }
     script += QLatin1String("global ");
@@ -71,7 +71,7 @@ void SieveGlobalVariableActionWidget::initWidget()
     QLabel *lab = new QLabel(i18n("Variable name:"));
     mLayout->addWidget(lab, 1, 0);
 
-    mVariableName = new QLineEdit;
+    mVariableName = new LineEditValidator;
     connect(mVariableName, &QLineEdit::textChanged, this, &SieveGlobalVariableActionWidget::valueChanged);
     mLayout->addWidget(mVariableName, 1, 1);
 
@@ -101,6 +101,13 @@ void SieveGlobalVariableActionWidget::initWidget()
     connect(mRemove, &QPushButton::clicked, this, &SieveGlobalVariableActionWidget::slotRemoveWidget);
 }
 
+void SieveGlobalVariableActionWidget::clear()
+{
+    mVariableName->clear();
+    mSetValueTo->setChecked(false);
+    mVariableValue->clear();
+}
+
 bool SieveGlobalVariableActionWidget::isInitialized() const
 {
     return !mVariableName->text().isEmpty();
@@ -108,7 +115,11 @@ bool SieveGlobalVariableActionWidget::isInitialized() const
 
 QString SieveGlobalVariableActionWidget::variableName() const
 {
-    return mVariableName->text();
+    const QString varName = mVariableName->text();
+    if (varName.trimmed().isEmpty()) {
+        return {};
+    }
+    return varName;
 }
 
 void SieveGlobalVariableActionWidget::setVariableValue(const QString &name)
@@ -118,21 +129,16 @@ void SieveGlobalVariableActionWidget::setVariableValue(const QString &name)
     mVariableValue->setEnabled(true);
 }
 
-void SieveGlobalVariableActionWidget::loadScript(const QDomElement &element, QString &error)
+void SieveGlobalVariableActionWidget::loadScript(QXmlStreamReader &element, QString &error)
 {
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("str")) {
-                mVariableName->setText(e.text());
-            } else {
-                error += i18n("Unknown tag \"%1\" during loading of variables.") + QLatin1Char('\n');
-                qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableActionWidget::loadScript unknown tagName " << tagName;
-            }
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("str")) {
+            mVariableName->setText(element.readElementText());
+        } else {
+            error += i18n("Unknown tag \"%1\" during loading of variables.") + QLatin1Char('\n');
+            qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableActionWidget::loadScript unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
 }
 
@@ -174,14 +180,16 @@ SieveGlobalVariableWidget::~SieveGlobalVariableWidget()
 
 void SieveGlobalVariableWidget::slotHelp()
 {
-    const QString help = i18n("A variable has global scope in all scripts that have declared it with the \"global\" command.  If a script uses that variable name without declaring it global, the name specifies a separate, non-global variable within that script.");
+    const QString help = i18n(
+        "A variable has global scope in all scripts that have declared it with the \"global\" command.  If a script uses that variable name without declaring it global, the name specifies a separate, non-global variable within that script.");
     const QUrl href = KSieveUi::SieveEditorUtil::helpUrl(KSieveUi::SieveEditorUtil::GlobalVariable);
     const QString fullWhatsThis = AutoCreateScriptUtil::createFullWhatsThis(help, href.toString());
     QWhatsThis::showText(QCursor::pos(), fullWhatsThis, mHelpButton);
 }
 
-void SieveGlobalVariableWidget::generatedScript(QString &script, QStringList &requires)
+void SieveGlobalVariableWidget::generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop)
 {
+    Q_UNUSED(inForEveryPartLoop)
     QString result;
     QStringList lst;
     mIncludeLister->generatedScript(result, lst);
@@ -191,14 +199,14 @@ void SieveGlobalVariableWidget::generatedScript(QString &script, QStringList &re
     }
 }
 
-void SieveGlobalVariableWidget::loadScript(const QDomElement &element, QString &error)
+void SieveGlobalVariableWidget::loadScript(QXmlStreamReader &element, QString &error)
 {
     mIncludeLister->loadScript(element, error);
 }
 
-void SieveGlobalVariableWidget::loadSetVariable(const QDomElement &element, QString &error)
+SieveGlobalVariableActionWidget::VariableElement SieveGlobalVariableWidget::loadSetVariable(QXmlStreamReader &element, QString &error)
 {
-    mIncludeLister->loadSetVariable(element, error);
+    return mIncludeLister->loadSetVariable(element, error);
 }
 
 SieveGlobalVariableLister::SieveGlobalVariableLister(QWidget *parent)
@@ -210,7 +218,6 @@ SieveGlobalVariableLister::SieveGlobalVariableLister(QWidget *parent)
 
 SieveGlobalVariableLister::~SieveGlobalVariableLister()
 {
-
 }
 
 void SieveGlobalVariableLister::slotAddWidget(QWidget *w)
@@ -270,8 +277,10 @@ void SieveGlobalVariableLister::reconnectWidget(SieveGlobalVariableActionWidget
 
 void SieveGlobalVariableLister::clearWidget(QWidget *aWidget)
 {
-    Q_UNUSED(aWidget);
-    //TODO
+    if (aWidget) {
+        SieveGlobalVariableActionWidget *widget = static_cast<SieveGlobalVariableActionWidget *>(aWidget);
+        widget->clear();
+    }
     Q_EMIT valueChanged();
 }
 
@@ -282,7 +291,7 @@ QWidget *SieveGlobalVariableLister::createWidget(QWidget *parent)
     return w;
 }
 
-void SieveGlobalVariableLister::loadScript(const QDomElement &element, QString &error)
+void SieveGlobalVariableLister::loadScript(QXmlStreamReader &element, QString &error)
 {
     SieveGlobalVariableActionWidget *w = static_cast<SieveGlobalVariableActionWidget *>(widgets().constLast());
     if (w->isInitialized()) {
@@ -292,38 +301,40 @@ void SieveGlobalVariableLister::loadScript(const QDomElement &element, QString &
     w->loadScript(element, error);
 }
 
-void SieveGlobalVariableLister::loadSetVariable(const QDomElement &element, QString &/*error*/)
+SieveGlobalVariableActionWidget::VariableElement SieveGlobalVariableLister::loadSetVariable(QXmlStreamReader &element, QString & /*error*/)
 {
+    SieveGlobalVariableActionWidget::VariableElement var;
     QString variableName;
     QString variableValue;
     int index = 0;
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("str")) {
-                if (index == 0) {
-                    variableName = e.text();
-                } else if (index == 1) {
-                    variableValue = e.text();
-                } else {
-                    qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableLister::loadSetVariable too many argument:" << index;
-                }
-                ++index;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("str")) {
+            if (index == 0) {
+                variableName = element.readElementText();
+            } else if (index == 1) {
+                variableValue = element.readElementText();
             } else {
-                qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableLister::loadSetVariable unknown tagName " << tagName;
+                qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableLister::loadSetVariable too many argument:" << index;
             }
+            ++index;
+        } else {
+            qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableLister::loadSetVariable unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
 
     const QList<QWidget *> lstWidget = widgets();
+    bool globalVariableFound = false;
     for (QWidget *widget : lstWidget) {
         SieveGlobalVariableActionWidget *w = static_cast<SieveGlobalVariableActionWidget *>(widget);
         if (w->variableName() == variableName) {
             w->setVariableValue(variableValue);
+            globalVariableFound = true;
         }
     }
+    if (!globalVariableFound) {
+        var.variableName = variableName;
+        var.variableValue = variableValue;
+    }
+    return var;
 }
-
