@@ -28,9 +28,8 @@ class QPushButton;
 class KLineEdit;
 class QGridLayout;
 class QCheckBox;
-class QDomElement;
-namespace KSieveUi
-{
+class QXmlStreamReader;
+namespace KSieveUi {
 class SieveHelpButton;
 class SieveIncludeLocation : public KComboBox
 {
@@ -58,8 +57,9 @@ public:
 
     void generatedScript(QString &script);
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
-    void loadScript(const QDomElement &element, QString &error);
+    void loadScript(QXmlStreamReader &element, QString &error);
     bool isInitialized() const;
+    void clear();
 
 private Q_SLOTS:
     void slotAddWidget();
@@ -78,7 +78,7 @@ private:
     QCheckBox *mOptional;
     QCheckBox *mOnce;
     SieveIncludeLocation *mLocation;
-    KLineEdit *mIncludeName;
+    QLineEdit *mIncludeName;
 };
 
 class SieveIncludeWidgetLister : public KPIM::KWidgetLister
@@ -89,7 +89,7 @@ public:
     ~SieveIncludeWidgetLister();
 
     void generatedScript(QString &script, QStringList &requires);
-    void loadScript(const QDomElement &element, QString &error);
+    void loadScript(QXmlStreamReader &element, QString &error);
 
 Q_SIGNALS:
     void valueChanged();
@@ -99,8 +99,8 @@ public Q_SLOTS:
     void slotRemoveWidget(QWidget *w);
 
 protected:
-    void clearWidget(QWidget *aWidget) Q_DECL_OVERRIDE;
-    QWidget *createWidget(QWidget *parent) Q_DECL_OVERRIDE;
+    void clearWidget(QWidget *aWidget) override;
+    QWidget *createWidget(QWidget *parent) override;
 private:
     void reconnectWidget(SieveIncludeActionWidget *w);
     void updateAddRemoveButton();
@@ -113,9 +113,9 @@ public:
     explicit SieveIncludeWidget(QWidget *parent = nullptr);
     ~SieveIncludeWidget();
 
-    void generatedScript(QString &script, QStringList &requires) Q_DECL_OVERRIDE;
+    void generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop) override;
 
-    void loadScript(const QDomElement &element, QString &error);
+    void loadScript(QXmlStreamReader &element, QString &error);
 
 private Q_SLOTS:
     void slotHelp();
