@@ -21,16 +21,16 @@
 #define SIEVESCRIPTBLOCKWIDGET_H
 
 #include "sievewidgetpageabstract.h"
+#include "sieveglobalvariablewidget.h"
 
 class QRadioButton;
 class QGroupBox;
 class QAbstractButton;
 class KComboBox;
 class QPushButton;
-class QDomElement;
+class QXmlStreamReader;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveConditionWidgetLister;
 class SieveActionWidgetLister;
 class SieveEditorGraphicalModeWidget;
@@ -48,14 +48,15 @@ public:
     explicit SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent = nullptr);
     ~SieveScriptBlockWidget();
 
-    void setPageType(PageType type) Q_DECL_OVERRIDE;
+    void setPageType(PageType type) override;
 
-    void generatedScript(QString &script, QStringList &requires) Q_DECL_OVERRIDE;
+    void generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop) override;
 
     MatchCondition matchCondition() const;
 
-    void loadScript(const QDomElement &element, bool onlyActions, QString &error);
+    void loadScript(QXmlStreamReader &element, bool onlyActions, QString &error);
 
+    void loadLocalVariable(const SieveGlobalVariableActionWidget::VariableElement &var);
 Q_SIGNALS:
     void addNewBlock(QWidget *widget, KSieveUi::SieveWidgetPageAbstract::PageType type);
 
