@@ -23,7 +23,6 @@
 #include "sieveforeverypartwidget.h"
 #include "sievescriptpage.h"
 #include "sieveincludewidget.h"
-#include "util/helper_p.h"
 
 #include <QHBoxLayout>
 #include <KMessageBox>
@@ -32,6 +31,7 @@
 #include <QPushButton>
 #include <KIconLoader>
 #include <QIcon>
+#include <QXmlStreamWriter>
 
 #include <QVBoxLayout>
 #include <QListWidget>
@@ -39,8 +39,7 @@
 #include <QDomElement>
 #include "libksieve_debug.h"
 
-namespace
-{
+namespace {
 inline const QString defaultScriptName()
 {
     return QStringLiteral("SCRIPTNAME: ");
@@ -50,8 +49,8 @@ inline const QString defaultScriptName()
 using namespace KSieveUi;
 
 SieveScriptListItem::SieveScriptListItem(const QString &text, QListWidget *parent)
-    : QListWidgetItem(text, parent),
-      mScriptPage(nullptr)
+    : QListWidgetItem(text, parent)
+    , mScriptPage(nullptr)
 {
 }
 
@@ -82,10 +81,15 @@ void SieveScriptListItem::setScriptPage(SieveScriptPage *page)
 QString SieveScriptListItem::generatedScript(QStringList &requires) const
 {
     QString script;
-    if (!mDescription.isEmpty()) {
-        script = QLatin1Char('#') + mDescription;
-        script.replace(QLatin1Char('\n'), QStringLiteral("\n#"));
-        script += QLatin1Char('\n');
+    if (!mDescription.trimmed().isEmpty()) {
+        const QStringList commentList = mDescription.split(QLatin1Char('\n'));
+        for (const QString &str : commentList) {
+            if (str.isEmpty()) {
+                script += QLatin1Char('\n');
+            } else {
+                script += QLatin1Char('#') + str + QLatin1Char('\n');
+            }
+        }
     }
     if (mScriptPage) {
         mScriptPage->generatedScript(script, requires);
@@ -94,9 +98,9 @@ QString SieveScriptListItem::generatedScript(QStringList &requires) const
 }
 
 SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
-    : QGroupBox(title, parent),
-      mSieveGraphicalModeWidget(nullptr),
-      mScriptNumber(0)
+    : QGroupBox(title, parent)
+    , mSieveGraphicalModeWidget(nullptr)
+    , mScriptNumber(0)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
     mSieveListScript = new QListWidget(this);
@@ -108,26 +112,26 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     hbHBoxLayout->setMargin(0);
     hbHBoxLayout->setSpacing(4);
 
-    mBtnTop = new QPushButton(QString(), hb);
+    mBtnTop = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnTop);
     mBtnTop->setIcon(QIcon::fromTheme(QStringLiteral("go-top")));
     mBtnTop->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnTop->setMinimumSize(mBtnTop->sizeHint() * 1.2);
 
-    mBtnUp = new QPushButton(QString(), hb);
+    mBtnUp = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnUp);
     mBtnUp->setAutoRepeat(true);
     mBtnUp->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     mBtnUp->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnUp->setMinimumSize(mBtnUp->sizeHint() * 1.2);
-    mBtnDown = new QPushButton(QString(), hb);
+    mBtnDown = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnDown);
     mBtnDown->setAutoRepeat(true);
     mBtnDown->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
     mBtnDown->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnDown->setMinimumSize(mBtnDown->sizeHint() * 1.2);
 
-    mBtnBottom = new QPushButton(QString(), hb);
+    mBtnBottom = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnBottom);
     mBtnBottom->setIcon(QIcon::fromTheme(QStringLiteral("go-bottom")));
     mBtnBottom->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
@@ -145,26 +149,33 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     hbHBoxLayout->setMargin(0);
     hbHBoxLayout->setSpacing(4);
 
-    mBtnNew = new QPushButton(QString(), hb);
+    mBtnNew = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnNew);
     mBtnNew->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
     mBtnNew->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnNew->setToolTip(i18n("New Script"));
     mBtnNew->setMinimumSize(mBtnNew->sizeHint() * 1.2);
 
-    mBtnDelete = new QPushButton(QString(), hb);
+    mBtnDelete = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnDelete);
     mBtnDelete->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     mBtnDelete->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnDelete->setToolTip(i18n("Delete Script"));
     mBtnDelete->setMinimumSize(mBtnDelete->sizeHint() * 1.2);
 
-    mBtnRename = new QPushButton(i18n("Rename..."), hb);
+    mBtnRename = new QPushButton(hb);
     mBtnRename->setToolTip(i18n("Rename Script"));
+    mBtnRename->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
+    mBtnRename->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnRename->setMinimumSize(mBtnRename->sizeHint() * 1.2);
     hbHBoxLayout->addWidget(mBtnRename);
 
-    mBtnDescription = new QPushButton(i18n("Edit description..."), hb);
+    mBtnDescription = new QPushButton(hb);
     mBtnDescription->setToolTip(i18n("Edit Script Description"));
+    mBtnDescription->setIcon(QIcon::fromTheme(QStringLiteral("edit-comment")));
+    mBtnDescription->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnDescription->setMinimumSize(mBtnDescription->sizeHint() * 1.2);
+
     hbHBoxLayout->addWidget(mBtnDescription);
 
     layout->addWidget(hb);
@@ -353,6 +364,9 @@ QString SieveScriptListBox::generatedScript(QString &requires) const
         resultScript += QLatin1Char('#') + defaultScriptName() + item->text() + QLatin1Char('\n');
         resultScript += item->generatedScript(lstRequires);
     }
+    if (!resultScript.isEmpty()) {
+        resultScript += QLatin1Char('\n');
+    }
 
     QStringList endRequires;
     for (const QString &r : qAsConst(lstRequires)) {
@@ -374,142 +388,169 @@ void SieveScriptListBox::clear()
     updateButtons();
 }
 
-void SieveScriptListBox::loadScript(const QDomDocument &doc, QString &error)
+void SieveScriptListBox::loadScript(const QString &doc, QString &error)
 {
     clear();
-    QDomElement docElem = doc.documentElement();
-    QDomNode n = docElem.firstChild();
-    SieveScriptPage *currentPage = nullptr;
-    ParseSieveScriptTypeBlock typeBlock = TypeUnknown;
-    loadBlock(n, currentPage, typeBlock, error);
+    QXmlStreamReader streamReader(doc);
+    if (streamReader.readNextStartElement()) {
+        if (streamReader.name() == QLatin1String("script")) {
+            SieveScriptPage *currentPage = nullptr;
+            ParseSieveScriptTypeBlock typeBlock = TypeUnknown;
+            loadBlock(streamReader, currentPage, typeBlock, error);
+        }
+    }
 }
 
-void SieveScriptListBox::loadBlock(QDomNode &n, SieveScriptPage *currentPage, ParseSieveScriptTypeBlock typeBlock, QString &error)
+void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *currentPage, ParseSieveScriptTypeBlock typeBlock, QString &error)
 {
     QString scriptName;
     QString comment;
     bool hasCreatedAIfBlock = false;
-    while (!n.isNull()) {
-        QDomElement e = n.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            //qCDebug(LIBKSIEVE_LOG)<<" tagName "<<tagName;
-            if (tagName == QLatin1String("control")) {
-                //Create a new page when before it was "onlyactions"
-                if (typeBlock == TypeBlockAction) {
-                    currentPage = nullptr;
-                }
-                if (e.hasAttribute(QStringLiteral("name"))) {
-                    const QString controlType = e.attribute(QStringLiteral("name"));
-                    //qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
-                    if (controlType == QLatin1String("if")) {
-                        typeBlock = TypeBlockIf;
-                        if (!currentPage || hasCreatedAIfBlock) {
-                            currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                        }
-                        hasCreatedAIfBlock = true;
-                        comment.clear();
-                        currentPage->blockIfWidget()->loadScript(e, false, error);
-                    } else if (controlType == QLatin1String("elsif")) {
-                        typeBlock = TypeBlockElsif;
-                        if (!currentPage) {
-                            qCDebug(LIBKSIEVE_LOG) << " script is not correct missing if block";
-                            currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                        }
-                        SieveScriptBlockWidget *blockWidget = currentPage->addScriptBlock(KSieveUi::SieveWidgetPageAbstract::BlockElsIf);
-                        if (blockWidget) {
-                            blockWidget->loadScript(e, false, error);
-                        }
-                    } else if (controlType == QLatin1String("else")) {
-                        typeBlock = TypeBlockElse;
-                        if (!currentPage) {
-                            currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                            qCDebug(LIBKSIEVE_LOG) << " script is not correct missing if block";
-                        }
-                        SieveScriptBlockWidget *blockWidget = currentPage->addScriptBlock(KSieveUi::SieveWidgetPageAbstract::BlockElse);
-                        if (blockWidget) {
-                            blockWidget->loadScript(e, false, error);
-                        }
-                        //We are sure that we can't have another elsif
-                        currentPage = nullptr;
-                    } else if (controlType == QLatin1String("foreverypart")) {
-                        typeBlock = TypeBlockForeachBlock;
-                        if (!currentPage) {
-                            currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                            comment.clear();
-                        }
-                        if (currentPage->forEveryPartWidget()) {
-                            currentPage->forEveryPartWidget()->loadScript(e, error);
-                        } else {
-                            error += i18n("forEveryPart is not supported by your server") + QLatin1Char('\n');
-                        }
-                        //TODO verify it.
-                        QDomNode block = e.firstChildElement(QStringLiteral("block")).firstChild();
-                        loadBlock(block, currentPage, typeBlock, error);
-                    } else if (controlType == QLatin1String("require")) {
-                        //Nothing. autogenerated
-                    } else {
-                        qCDebug(LIBKSIEVE_LOG) << " unknown controlType :" << controlType;
-                    }
-                }
-            } else if (tagName == QLatin1String("comment")) {
-                QString str(e.text());
-                if (str.contains(defaultScriptName())) {
-                    scriptName = str.remove(defaultScriptName());
-                } else {
-                    if (!comment.isEmpty()) {
-                        comment += QLatin1Char('\n');
-                    }
-                    comment += e.text();
-                }
-            } else if (tagName == QLatin1String("action")) {
-                if (e.hasAttribute(QStringLiteral("name"))) {
-                    const QString actionName = e.attribute(QStringLiteral("name"));
-                    if (actionName == QLatin1String("include")) {
-                        if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
-                            currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                            comment.clear();
-                        }
-                        typeBlock = TypeBlockInclude;
-                        if (currentPage->includeWidget()) {
-                            currentPage->includeWidget()->loadScript(e, error);
-                        } else {
-                            qCDebug(LIBKSIEVE_LOG) << " include not supported";
-                        }
-                    } else if (actionName == QLatin1String("global")) {
-                        if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
-                            currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                            comment.clear();
-                        }
-                        typeBlock = TypeBlockGlobal;
-                        if (currentPage->globalVariableWidget()) {
-                            currentPage->globalVariableWidget()->loadScript(e, error);
-                        } else {
-                            qCDebug(LIBKSIEVE_LOG) << " globalVariable not supported";
-                        }
-                    } else if (actionName == QLatin1String("set") && (typeBlock == TypeBlockGlobal)) {
-                        if (currentPage->globalVariableWidget()) {
-                            currentPage->globalVariableWidget()->loadSetVariable(e, error);
-                        } else {
-                            qCDebug(LIBKSIEVE_LOG) << " globalVariable not supported";
-                        }
-                    } else {
-                        if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
-                            currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                        }
-                        typeBlock = TypeBlockAction;
-                        comment.clear();
-                        currentPage->blockIfWidget()->loadScript(e, true, error);
-                        //qCDebug(LIBKSIEVE_LOG)<<" unknown action name: "<<actionName;
-                    }
-                }
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else {
-                qCDebug(LIBKSIEVE_LOG) << " unknown tagname" << tagName;
+    bool previousElementWasAComment = false;
+    while (n.readNextStartElement()) {
+        const QStringRef tagName = n.name();
+        //qDebug() <<"SieveScriptListBox::loadBlock tagName " << tagName;
+        if (tagName == QLatin1String("control")) {
+            previousElementWasAComment = false;
+            //Create a new page when before it was "onlyactions"
+            if (typeBlock == TypeBlockAction) {
+                currentPage = nullptr;
             }
+            if (n.attributes().hasAttribute(QStringLiteral("name"))) {
+                const QString controlType = n.attributes().value(QStringLiteral("name")).toString();
+                //qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
+                if (controlType == QLatin1String("if")) {
+                    typeBlock = TypeBlockIf;
+                    if (!currentPage || hasCreatedAIfBlock) {
+                        currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                    }
+                    hasCreatedAIfBlock = true;
+                    comment.clear();
+                    currentPage->blockIfWidget()->loadScript(n, false, error);
+                } else if (controlType == QLatin1String("elsif")) {
+                    typeBlock = TypeBlockElsif;
+                    if (!currentPage) {
+                        qCDebug(LIBKSIEVE_LOG) << " script is not correct missing if block";
+                        currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                    }
+                    SieveScriptBlockWidget *blockWidget = currentPage->addScriptBlock(KSieveUi::SieveWidgetPageAbstract::BlockElsIf);
+                    if (blockWidget) {
+                        blockWidget->loadScript(n, false, error);
+                    }
+                } else if (controlType == QLatin1String("else")) {
+                    typeBlock = TypeBlockElse;
+                    if (!currentPage) {
+                        currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                        qCDebug(LIBKSIEVE_LOG) << " script is not correct missing if block";
+                    }
+                    SieveScriptBlockWidget *blockWidget = currentPage->addScriptBlock(KSieveUi::SieveWidgetPageAbstract::BlockElse);
+                    if (blockWidget) {
+                        blockWidget->loadScript(n, false, error);
+                    }
+                    //We are sure that we can't have another elsif
+                    currentPage = nullptr;
+                } else if (controlType == QLatin1String("foreverypart")) {
+                    typeBlock = TypeBlockForeachBlock;
+                    if (!currentPage) {
+                        currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                        comment.clear();
+                    }
+                    if (currentPage->forEveryPartWidget()) {
+                        currentPage->forEveryPartWidget()->loadScript(n, error);
+                    } else {
+                        error += i18n("forEveryPart is not supported by your server") + QLatin1Char('\n');
+                    }
+                    //TODO verify it.
+#ifdef QDOMELEMENT_FIXME
+                    QDomNode block = e.firstChildElement(QStringLiteral("block")).firstChild();
+                    loadBlock(block, currentPage, typeBlock, error);
+#endif
+                } else if (controlType == QLatin1String("require")) {
+                    n.skipCurrentElement();
+                    //Nothing. autogenerated
+                } else {
+                    qCDebug(LIBKSIEVE_LOG) << " unknown controlType :" << controlType;
+                }
+            }
+        } else if (tagName == QLatin1String("comment")) {
+            previousElementWasAComment = true;
+#ifdef QDOMELEMENT_FIXME
+            if (e.hasAttribute(QStringLiteral("hash"))) {
+                //TODO
+            } else if (e.hasAttribute(QStringLiteral("bracket"))) {
+                //TODO
+            }
+#endif
+            QString str(n.readElementText());
+            if (str.contains(defaultScriptName())) {
+                scriptName = str.remove(defaultScriptName());
+            } else {
+                if (!comment.isEmpty()) {
+                    comment += QLatin1Char('\n');
+                }
+                comment += str;
+            }
+            //qDebug() << " COMMENT " << comment;
+        } else if (tagName == QLatin1String("action")) {
+            previousElementWasAComment = false;
+            if (n.attributes().hasAttribute(QStringLiteral("name"))) {
+                const QString actionName = n.attributes().value(QStringLiteral("name")).toString();
+                if (actionName == QLatin1String("include")) {
+                    if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
+                        currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                        comment.clear();
+                    }
+                    typeBlock = TypeBlockInclude;
+                    if (currentPage->includeWidget()) {
+                        currentPage->includeWidget()->loadScript(n, error);
+                    } else {
+                        qCDebug(LIBKSIEVE_LOG) << " include not supported";
+                    }
+                } else if (actionName == QLatin1String("global")) {
+                    if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
+                        currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                        comment.clear();
+                    }
+                    typeBlock = TypeBlockGlobal;
+                    if (currentPage->globalVariableWidget()) {
+                        currentPage->globalVariableWidget()->loadScript(n, error);
+                    } else {
+                        qCDebug(LIBKSIEVE_LOG) << " globalVariable not supported";
+                    }
+                } else if (actionName == QLatin1String("set") && (typeBlock == TypeBlockGlobal)) {
+                    //FIXME global not global variable.
+                    if (currentPage->globalVariableWidget()) {
+                        const SieveGlobalVariableActionWidget::VariableElement var = currentPage->globalVariableWidget()->loadSetVariable(n, error);
+                        if (var.isValid()) {
+                            qCDebug(LIBKSIEVE_LOG) << "It's not a global variable";
+                            if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
+                                currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                            }
+                            typeBlock = TypeBlockAction;
+                            comment.clear();
+                            currentPage->blockIfWidget()->loadLocalVariable(var);
+                        }
+                    } else {
+                        qCDebug(LIBKSIEVE_LOG) << " set not supported";
+                    }
+                } else {
+                    if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
+                        currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                    }
+                    typeBlock = TypeBlockAction;
+                    comment.clear();
+                    currentPage->blockIfWidget()->loadScript(n, true, error);
+                }
+            }
+        } else if (tagName == QLatin1String("crlf")) {
+            //If it was a comment previously you will create a \n
+            if (previousElementWasAComment) {
+                comment += QLatin1Char('\n');
+            }
+            n.skipCurrentElement();
+        } else {
+            qCDebug(LIBKSIEVE_LOG) << " unknown tagname" << tagName;
         }
-        n = n.nextSibling();
     }
 }
 
@@ -519,4 +560,3 @@ QString SieveScriptListBox::createUniqName()
     ++mScriptNumber;
     return pattern;
 }
-
