@@ -73,7 +73,7 @@ int main(int argc, char **argv)
 
     KSieve::Parser sieveParser(script.begin(),
                                script.begin() + script.length());
-    KSieveUi::XMLPrintingScriptBuilder psb;
+    KSieveUi::XMLPrintingScriptBuilder psb(2);
     sieveParser.setScriptBuilder(&psb);
     if (sieveParser.parse()) {
         qDebug() << "ok";
@@ -81,7 +81,7 @@ int main(int argc, char **argv)
         qDebug() << "bad";
     }
     KSieveUi::ParsingResultDialog dlg;
-    dlg.setResultParsing(psb.toDom().toString());
+    dlg.setResultParsing(psb.result());
     dlg.show();
 
     KSieveUi::AutoCreateScriptDialog *dialog = new KSieveUi::AutoCreateScriptDialog;
@@ -90,7 +90,7 @@ int main(int argc, char **argv)
     //Add all capabilities for testing
     dialog->setSieveCapabilities(capabilities);
     QString error;
-    dialog->loadScript(psb.toDom(), error);
+    dialog->loadScript(psb.result(), error);
     if (!error.isEmpty()) {
         QPointer<KSieveUi::SieveScriptParsingErrorDialog> dlg = new KSieveUi::SieveScriptParsingErrorDialog;
         dlg->setError(QString::fromLatin1(script), error);
@@ -103,4 +103,3 @@ int main(int argc, char **argv)
     delete dialog;
     return 0;
 }
-
