@@ -22,8 +22,7 @@
 
 class QAction;
 class QMenu;
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveEditorTextModeWidget;
 class SieveEditorMenuBar : public QMenuBar
 {
