@@ -50,15 +50,14 @@ class KSieveUi::ManageSieveScriptsDialogPrivate
 {
 public:
     ManageSieveScriptsDialogPrivate()
-        : mSieveEditor(nullptr),
-          mNewScript(nullptr),
-          mEditScript(nullptr),
-          mDeleteScript(nullptr),
-          mDeactivateScript(nullptr),
-          mIsNewScript(false),
-          mWasActive(false)
+        : mSieveEditor(nullptr)
+        , mNewScript(nullptr)
+        , mEditScript(nullptr)
+        , mDeleteScript(nullptr)
+        , mDeactivateScript(nullptr)
+        , mIsNewScript(false)
+        , mWasActive(false)
     {
-
     }
 
     CustomManageSieveWidget *mTreeView;
@@ -77,15 +76,16 @@ public:
     bool mWasActive : 1;
 };
 
-ManageSieveScriptsDialog::ManageSieveScriptsDialog(QWidget *parent)
-    : QDialog(parent),
-      d(new KSieveUi::ManageSieveScriptsDialogPrivate)
+ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *passwordProvider, QWidget *parent)
+    : QDialog(parent)
+    , d(new KSieveUi::ManageSieveScriptsDialogPrivate)
 {
     setWindowTitle(i18n("Manage Sieve Scripts"));
     setModal(false);
     setAttribute(Qt::WA_GroupLeader);
     setAttribute(Qt::WA_DeleteOnClose);
-    KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small), IconSize(KIconLoader::Small)));
+    KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)),
+                            qApp->windowIcon().pixmap(IconSize(KIconLoader::Small), IconSize(KIconLoader::Small)));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QFrame *frame = new QFrame;
     mainLayout->addWidget(frame);
@@ -93,7 +93,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(QWidget *parent)
     vlay->setSpacing(0);
     vlay->setMargin(0);
 
-    d->mTreeView = new CustomManageSieveWidget(frame);
+    d->mTreeView = new CustomManageSieveWidget(passwordProvider, frame);
     connect(d->mTreeView, &CustomManageSieveWidget::editScript, this, &ManageSieveScriptsDialog::slotEditScript);
     connect(d->mTreeView, &CustomManageSieveWidget::newScript, this, &ManageSieveScriptsDialog::slotNewScript);
     connect(d->mTreeView, &CustomManageSieveWidget::updateButtons, this, &ManageSieveScriptsDialog::slotUpdateButtons);
@@ -282,4 +282,3 @@ void ManageSieveScriptsDialog::disableManagerScriptsDialog(bool disable)
 {
     setDisabled(disable);
 }
-
