@@ -21,12 +21,10 @@
 #include "ksieveui_private_export.h"
 #include <QDialog>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
-namespace KSieveUi
-{
+namespace KSieveUi {
 class KSIEVEUI_TESTS_EXPORT ParsingResultDialog : public QDialog
 {
     Q_OBJECT
