@@ -27,15 +27,15 @@
 
 class QUrl;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class CheckKolabKep14SupportJob;
 class VacationCheckJob;
+class SieveImapPasswordProvider;
 class KSIEVEUI_EXPORT MultiImapVacationManager : public QObject
 {
     Q_OBJECT
 public:
-    explicit MultiImapVacationManager(QObject *parent = nullptr);
+    explicit MultiImapVacationManager(SieveImapPasswordProvider *passwordProvider, QObject *parent = nullptr);
     ~MultiImapVacationManager();
 
     void checkVacation();
@@ -52,6 +52,7 @@ private Q_SLOTS:
     void slotCheckKep14Ended(KSieveUi::CheckKolabKep14SupportJob *job, bool success);
 
 private:
+    SieveImapPasswordProvider *mPasswordProvider;
     int mNumberOfJobs;
     bool mCheckInProgress;
 
